==> cargo-core-api-container-0.9-sources.jar: org/codehaus/cargo/container/spi/configuration/AbstractStandaloneLocalConfigurationCapability.java <==
/* 
 * ========================================================================
 * 
 * Copyright 2004-2005 Vincent Massol.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * ========================================================================
 */
package org.codehaus.cargo.container.spi.configuration;

import org.codehaus.cargo.container.property.GeneralPropertySet;
import org.codehaus.cargo.container.property.ServletPropertySet;

/**
 * Base implementation of {@link org.codehaus.cargo.container.configuration.ConfigurationCapability}
 * that needs to be extended by each standalone configuration's implementation.
 *  
 * @version $Id: AbstractStandaloneLocalConfigurationCapability.java 969 2006-03-27 11:34:18Z vmassol $
 */
public abstract class AbstractStandaloneLocalConfigurationCapability
    extends AbstractConfigurationCapability
{
    /**
     * {@inheritDoc}
     * @see org.codehaus.cargo.container.spi.configuration.AbstractConfigurationCapability#AbstractConfigurationCapability()
     */
    public AbstractStandaloneLocalConfigurationCapability()
    {
        super();

        this.defaultSupportsMap.put(GeneralPropertySet.LOGGING, Boolean.TRUE);
        this.defaultSupportsMap.put(GeneralPropertySet.PROTOCOL, Boolean.TRUE);
        this.defaultSupportsMap.put(GeneralPropertySet.HOSTNAME, Boolean.TRUE);
        this.defaultSupportsMap.put(GeneralPropertySet.JVMARGS, Boolean.TRUE);

        this.defaultSupportsMap.put(ServletPropertySet.PORT, Boolean.TRUE);
        this.defaultSupportsMap.put(ServletPropertySet.USERS, Boolean.TRUE);
    }
}

==> cargo-core-api-container-1.10.22-sources.jar: org/codehaus/cargo/container/spi/configuration/AbstractStandaloneLocalConfigurationCapability.java <==
/*
 * ========================================================================
 *
 * Codehaus Cargo, copyright 2004-2011 Vincent Massol, 2012-2025 Ali Tokmen.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * ========================================================================
 */
package org.codehaus.cargo.container.spi.configuration;

import org.codehaus.cargo.container.property.GeneralPropertySet;
import org.codehaus.cargo.container.property.ServletPropertySet;

/**
 * Base implementation of {@link org.codehaus.cargo.container.configuration.ConfigurationCapability}
 * that needs to be extended by each standalone configuration's implementation.
 */
public abstract class AbstractStandaloneLocalConfigurationCapability
    extends AbstractLocalConfigurationCapability
{
    /**
     * {@inheritDoc}
     * @see AbstractLocalConfigurationCapability#AbstractLocalConfigurationCapability()
     */
    public AbstractStandaloneLocalConfigurationCapability()
    {
        this.propertySupportMap.put(GeneralPropertySet.PROTOCOL, Boolean.FALSE);
        this.propertySupportMap.put(GeneralPropertySet.LOGGING, Boolean.TRUE);
        this.propertySupportMap.put(GeneralPropertySet.IGNORE_NON_EXISTING_PROPERTIES,
            Boolean.TRUE);
        this.propertySupportMap.put(ServletPropertySet.USERS, Boolean.TRUE);
    }
}
